<?php
$TRANSLATIONS = array(
"Access granted" => "Alirpermeso donita",
"Error configuring Dropbox storage" => "Eraro dum agordado de la memorservo Dropbox",
"Grant access" => "Doni alirpermeson",
"Please provide a valid Dropbox app key and secret." => "Bonvolu provizi ŝlosilon de la aplikaĵo Dropbox validan kaj sekretan.",
"Error configuring Google Drive storage" => "Eraro dum agordado de la memorservo Google Drive",
"External Storage" => "Malena memorilo",
"Folder name" => "Dosierujnomo",
"Configuration" => "Agordo",
"Options" => "Malneproj",
"Applicable" => "Aplikebla",
"None set" => "Nenio agordita",
"All Users" => "Ĉiuj uzantoj",
"Groups" => "Grupoj",
"Users" => "Uzantoj",
"Delete" => "Forigi",
"Enable User External Storage" => "Kapabligi malenan memorilon de uzanto",
"Allow users to mount their own external storage" => "Permesi al uzantoj surmeti siajn proprajn malenajn memorilojn",
"SSL root certificates" => "Radikaj SSL-atestoj",
"Import Root Certificate" => "Enporti radikan ateston"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
